'use client'

import { useState, useEffect, useCallback } from 'react'
import { FiEdit2, FiTrash2, FiPlus, FiList } from 'react-icons/fi'
import DashboardLayout from '../../../components/layout/DashboardLayout'
import Link from 'next/link'
import { categoryService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { getDate } from '@/config/tableConfig'
export default function CategoriesPage() {
  const { user } = useUser()
  const [categories, setCategories] = useState([])
  const [error, setError] = useState(false)

  const fetchCategories = useCallback(async () => {
    try {
      const response = await categoryService.index(user?.token || '')
      setCategories(response.data.categories)
    } catch (error) {
      setError(true)
    }
  }, [user?.token])

  const handleDelete = async (id: number) => {
    try {
      const response = await categoryService.destroy(id.toString(), user?.token || '')
      fetchCategories()
    } catch (error) {
      console.error('Kategori silinirken hata:', error)
      setError(true)
    }
  }

  useEffect(() => {
    fetchCategories()
  }, [user?.token, fetchCategories])

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex flex-col sm:flex-row sm:items-center justify-between gap-4">
          <div>
            <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
              Kategori Listesi
            </h1>
            <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
              Tüm kategorileri görüntüle, düzenle ve yönet
            </p>
          </div>
          <Link
            href="/dashboard/categories/add"
            className="inline-flex items-center gap-2 px-4 py-2.5 text-sm font-medium 
                     text-white bg-gradient-to-r from-fuchsia-500 to-purple-600 
                     rounded-xl hover:opacity-90 transition-all"
          >
            <FiPlus className="w-4 h-4" />
            Yeni Kategori
          </Link>
        </div>

        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg border border-slate-200/50 dark:border-slate-700/50">
          <div className="overflow-x-auto">
            <table className="w-full">
              <thead>
                <tr className="border-b border-slate-200/50 dark:border-slate-700/50">
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4">
                    Kategori Adı
                  </th>
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4">
                    Ürün Sayısı
                  </th>
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4 hidden sm:table-cell">
                    Oluşturulma Tarihi
                  </th>
                  <th className="text-right text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4">
                    İşlemler
                  </th>
                </tr>
              </thead>
              <tbody>
                {categories.map((category: any) => (
                  <tr
                    key={category.id}
                    className="border-b border-slate-200/50 dark:border-slate-700/50 last:border-0
                             hover:bg-slate-50/50 dark:hover:bg-slate-700/50 transition-colors"
                  >
                    <td className="px-6 py-4 whitespace-nowrap">
                      <div className="flex items-center gap-3">
                        <div className="w-10 h-10 rounded-lg bg-gradient-to-r from-fuchsia-500 to-purple-600 
                                    flex items-center justify-center shadow-lg">
                          <FiList className="w-5 h-5 text-white" />
                        </div>
                        <span className="text-sm font-medium text-slate-700 dark:text-slate-200">
                          {category.name}
                        </span>
                      </div>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap">
                      <span className="inline-flex items-center px-2.5 py-1 rounded-full text-xs font-medium
                                   bg-fuchsia-100/50 dark:bg-fuchsia-900/50 
                                   text-fuchsia-600 dark:text-fuchsia-400">
                        {category.product_count || 0} Ürün
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap hidden sm:table-cell">
                      <span className="text-sm text-slate-500 dark:text-slate-400">
                        {getDate(category.created_at)}
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap text-right">
                      <div className="flex items-center justify-end gap-2">
                        <Link
                          href={`/dashboard/categories/edit/${category.id}`}
                          className="p-2 rounded-lg bg-slate-100/50 dark:bg-slate-700/50 
                                   text-slate-600 dark:text-slate-300 
                                   hover:bg-fuchsia-50 dark:hover:bg-slate-600/50 
                                   hover:text-fuchsia-500 transition-colors"
                        >
                          <FiEdit2 className="w-4 h-4" />
                        </Link>
                        <button
                          onClick={() => handleDelete(category.id)}
                          className="p-2 rounded-lg bg-slate-100/50 dark:bg-slate-700/50 
                                   text-slate-600 dark:text-slate-300 
                                   hover:bg-red-50 dark:hover:bg-red-900/10 
                                   hover:text-red-500 transition-colors"
                        >
                          <FiTrash2 className="w-4 h-4" />
                        </button>
                      </div>
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </DashboardLayout>
  )
} 